if(!dojo._hasResource["com.ibm.customize.ChangeLayoutController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.ChangeLayoutController"] = true;
// This is a controller that customizes the styles of a page

dojo.provide("com.ibm.customize.ChangeLayoutController");

com.ibm.customize.ChangeLayoutController = {
	current: "",			// the style currently selected on the shelf
	currentSet: "",				// the style currently set on the page

/***********************************************/
/*       Customize Controller API			   */
/***********************************************/
	store: null,		// a datastore to save model changes
	item: null,			// an item in the store representing the current page to which changes will be made
	parent: null,		// a pointer to this controller's parent, if one exists
	dirty: false,		// true if there are changes pending
	started: false,		// true if the widget is started up
	refresh: true,		// true if a page refresh is required to show saved changes
	portletMaximized: false,// true if there is a maximized portlet on the page

	startup: function(/*Object?/Widget?*/parent){
		// summary: set some variable and set up the UI
		// parent: a reference to the parent of this controller
		this.started = true;
		this.parent = parent;
		this.current = this.currentSet;
		this.pageId = this.store.getIdentity(this.item).substr(3);
		
		if (this.portletMaximized) {
			// display a warning message that no portlet can be in maxmized mode if the layout is to be changed
			var warningMsg = this.createLotusMsgNode(this.nlsBundle.change_layout_maximizedError || "The layout cannot be changed while there is a portlet in maximized mode", "Warning");
			dojo.style(warningMsg, "margin", "20px");
			this.domNode.innerHTML = "";
			this.domNode.appendChild(warningMsg);
		}
		else {
			if (this.setupUI) {
				this.setupUI();
			}
		}
	},
	
	_fullLMId: function(lmId) {
		return "lm:" + lmId + "@" + this.pageId;
	},
		
	makeDirty: function(/*bool*/change){
		// summary: changes the dirty attribute
		// change: value to assign to the dirty attribute
		this.dirty = change;
	},
		
	processChange: function(/*Object*/args){
		// summary: used as an event handler for when a user clicks on a result
		this.apply(args);
		if(!this.parent) {
			this.beforeSubmit().addCallback(dojo.hitch(this, function(){this.submit(args);}));
		}
	},
		
	apply: function(/*Object*/args){
		// summary: applies a change associated with a result to the page
		// args: contains args.id which is the id of the selected item
		if (args.id == this.current) {
			return;
		}
		if (args.id == this.currentSet) {
			this.makeDirty(false);
		}
		else {
			if (this.dirty == false) {
				this.makeDirty(true);
			}
		}
		this.current = args.id;
	},
		
	undo: function(){
		// summary: reverts any changes made
		if (this.started) {
			this.apply({
				id: this.currentSet
			});
		}
	},

	beforeSubmit: function(/*Object*/args){
		// summary: set the metadata for the style in the content model store. Returns a Deferred
		//		which is fired when the controller is ready to be submitted.
		var dfd = new dojo.Deferred();
		if (this.dirty) {
			var cbk = dojo.hitch(this, function(){
				if (this.started) {
					this.store.setValue(this.item, "metadata[layout]$", this.current);
				}
				this._loadLayout(dojo.hitch(this, function(root){
					this._getTreeModel().getChildren(root, dojo.hitch(this, "_calculateLayoutChanges", root, dfd));
				}));
			});
			if (!this.store.isItemLoaded(this.item)) {
				this.store.loadItem({
					item: this.item,
					onItem: cbk,
					onError: args ? args.onError : null
				});
			}
			else {
				cbk();
			}
		}
		else {
			dfd.callback();
		}
		return dfd;
	},
		
	submit: function(/*Object*/args){
		// summary: saves any pending changes to the server
		// args: args may contain an onComplete handler
		if(!this.dirty) {
			if (args.onComplete) {
				args.onComplete();
			}
			return; 
		}
		this._saveStore(args);
	},
	
	_calculateLayoutChanges: function(layoutRoot, deferred) {
		var newNumCols = this.columnHash[this.current];
		var oldNumCols = this.columnHash[this.currentSet];
		// change the number of containers in the backend			
		if(!oldNumCols){
			// case 0: transition away from a legacy layout
			this.removeLegacyLayout(newNumCols, layoutRoot, deferred);
		} else if(newNumCols > oldNumCols){ 
			// case 1: less to more containers; add extra containers
			this.addContainers(newNumCols-oldNumCols, layoutRoot);
		} else if(oldNumCols > newNumCols) { 
			// case 2: more to less containers
			var domContainers = dojo.query(".ibmPortalLayoutContainer"); 	// all containers on the page
			if(domContainers.length > newNumCols){  // safeguard if there are less containers than expected
				var parentContainerId = this._fullLMId(domContainers[newNumCols-1].id);			// the last container in the new layout will receive all orphaned controls
				var containersToDelete = [];
				var controlsToReparent = [];
				// loop through all containers to be deleted
				for(var i = oldNumCols; i != newNumCols; i--){
					if(domContainers[i-1]){ // safeguard in case there aren't as many layout containers as expected
						var removeContainer = domContainers[i-1].id;
						containersToDelete.push(this.store.byId(this._fullLMId(removeContainer))); // container to be deleted
						// controls to reparent
						var controls = dojo.query(".ibmPortalControlContainer",dojo.byId(removeContainer)); 
						// loop through all controls to reparent
						for(var j = 0; j < controls.length; j++){
							controlsToReparent.push(this.store.byId(this._fullLMId(controls[j].getAttribute("controlid"))));
						}
					}
				}
				// reparent the controls and then delete the containers they were in
				if(controlsToReparent.length > 0) {
					this.reparentControls(controlsToReparent, parentContainerId);
					this.deleteContainers(containersToDelete);
				} else if (containersToDelete.length > 0) {
					this.deleteContainers(containersToDelete);
				}
			}
		}
		if (oldNumCols) {
			deferred.callback();
		}
	},
	
	_saveStore: function(args,unfinished) {
		this.store.save({
			onComplete: dojo.hitch(this, function(){
				if (!unfinished) {
					this.makeDirty(false);
				}
				this.currentSet = this.current;
				if (args.onComplete) {
					args.onComplete();
				}
			}),
			onError: args.onError
		});
	},
	
	_getTreeModel: function() {
		// gets the tree model for the store which contains the item
		return this.store.getValue(this.item, "layoutModel");
	},
	
	_loadLayout: function(onItem, onError) {
		// summary: this loads the root layout node, but also the entire layout tree
		this._getTreeModel().getRoot(onItem, onError);		
	},
	
	addContainers: function(/*int*/num,/*item*/rootItem){
		// summary: add containers to the layout model of the current page
		// num: the number of containers to add
		// rootItem: datastore item for the root layout node
		var first = null;
		for(var i = 0; i < num; i++){ 
			var item = this.store.newItem({
				pocType: "lm",
				type: "container"
			}, {parent:rootItem});
			if (i === 0) {
				first = item;
			}
		}
		return first;
	},
	
	reparentControls: function(/*Array*/controlsToReparent,/*string*/parent){
		// summary: reparents given controls into a given container on the current page
		// controlsToReparent: an array of the IDs of the controls to reparent
		// parent: the ID of the container on the page which is the new parent
		for(var i = 0, control; i < controlsToReparent.length; i++){
			this.store.setValue(controlsToReparent[i], "parentId", parent); 
		}
	},
	
	deleteContainers: function(/*Array*/containersToDelete){
		// summary: deletes the given containers from the layout model of the current page
		// containersToDelete: an array of the IDs of the containers to delete off the page
		for(var i = 0; i < containersToDelete.length; i++){
			this.store.deleteItem(containersToDelete[i]);
		}
	},
	
	removeLegacyLayout: function(/*int*/num,/*item*/rootItem, deferred){ 
		// summary: removes a legacy layout by:
		//			1. creating the number of containers needed for the new layout
		//			2. moving ALL controls into the first of the newly created containers
		//			3. deleting all containers from the legacy layout which are direct children of the root layout node
		// num: the number of columns to create for the new layout
		// rootItem: datastore item for the root layout node
		var layoutModelItems = this._getTreeModel().getAll();
		var controlsToReparent = dojo.filter(layoutModelItems, function(item) {
			return this.store.getValue(item, "modelNodeType", "").toLowerCase() == "layout-control";
		}, this);
		var containersToDelete = dojo.filter(layoutModelItems, function(item) {
			return this.store.getValue(item, "parentId", "") == this.store.getValue(rootItem,"id");
		}, this);
		var newParentItem = this.addContainers(num,rootItem);
		if (controlsToReparent.length > 0) {
			this.reparentControls(controlsToReparent, this.store.getValue(newParentItem, "id"));
		}
		var deleteOldContainers = dojo.hitch(this, function(){
			if (containersToDelete.length > 0) {
				this.deleteContainers(containersToDelete);
			}
			deferred.callback();
		});
		this._saveStore({onComplete:deleteOldContainers},true);
	}
};

}
