dojo.provide("com.ibm.pb.decorations.DirectionalMoveControls");

dojo.require("com.ibm.pb.logging.Loggable");
dojo.require("com.ibm.pb.localized.DojoLocalized");
dojo.require("com.ibm.pb.screen.position");
dojo.require("com.ibm.pb.layout.LayoutParser");

/**
 * Provides controls to move a node between containers or between siblings in its own container
 */
dojo.declare("com.ibm.pb.decorations.DirectionalMoveControls", [com.ibm.mashups.builder.model.ContextMenuLoader, com.ibm.pb.logging.Loggable], {
	
	layoutParser: com.ibm.pb.layout.LayoutParser,
	
	directions: ["up", "down", "left", "right"],
	contentsQuery: ">",
	containerQuery: "div",
		
	constructor: function(args) {
		if(args) {
			dojo.safeMixin(this, args);
		}
	},
	getItems: function(/*String*/ contextMenuId, /*String*/ targetResourceId, /*String*/ targetResourceType, /*Object*/ someObject) {
		var mname = "getItems", lgr = this.LOGGER, me = this;
		lgr.entering(mname, arguments);
		dfd = new com.ibm.mm.builder.DeferredImpl(this, function(deferred, sync, params) {
			var callBack = deferred.getFinishedCallback(), callBackParams = deferred.getFinishedCallbackParameters(),
				ret = this.getControls(targetResourceId);
			if(callBack) {
				callBack(ret, 200, callBackParams);
			}
			return ret;
		});
		lgr.exiting(mname, arguments);
		return dfd;
	},
	getControls: function(node) {
		var ret = [], ordinal = 1;
		node = this.layoutParser.findById(node);
		if(node) {
			var nodeContainer = this.getContainer(node);
			var isFreeformLayoutContainer = dojo.hasClass(nodeContainer, "ibmFreeform");
			dojo.forEach(this.directions, function(dir){
				if(isFreeformLayoutContainer){
					var container = this.getContainerByDirection(node, dir);
					if(container){
						ret.push(dojo.mixin(this._getItem(dir), {
						ordinal: ordinal++,
						actionCallBackFunction: this.getMoveAction(node, container, sibling, dir)
					}));
					}
				}else{
					var sibling = this.getSiblingByDirection(node, dir), container = null;
				if(!sibling) {
					container = this.getContainerByDirection(node, dir);
				}
				if(sibling || container) {
					ret.push(dojo.mixin(this._getItem(dir), {
						ordinal: ordinal++,
						actionCallBackFunction: this.getMoveAction(node, sibling ? nodeContainer : container, sibling, dir)
					}));
				}
				}
			}, this);
		}
		return ret;
	},
	_getItem: function(dir) {
		return {
			id: "DirectionalMove:" + dir,
			localized: new com.ibm.pb.localized.DojoLocalized({
				bundlePackage: "com.ibm.bundles",
				bundleName: "Theme",
				bundleKey: "move_" + dir
			}),
			enabled: true
		};
	},
	nextElementSibling: function(node) {
		var next = node && node.nextSibling;
		if(!next) {
			return null;
		}
		else if(next.nodeType != 1) {
			return this.nextElementSibling(next);
		}
		else {
			return next;
		}
	},
	getPostMoveAction: function(node, parentNode, nextSibling) {
		return function(){};
	},
	onMove: function(node, refNode, position) {
		this.onChange();
	},
	moveNode: function(node, refNode, position) {
		dojo.place(node, refNode, position);
		this.onMove(node, refNode, position);
	},
	getMoveAction: function(childNode, parentNode, siblingNode, dir) {
		var mname = "getMoveAction", lgr = this.LOGGER, pos = "last", func, postMove, me = this, refNode;
		if(siblingNode && siblingNode.parentNode == parentNode) {
			// if we're here, we're just swapping node positions, we don't use dir explicitly
			// because it has already been calculated by examining nodes in the DOM
			pos = this._isBefore(childNode, siblingNode) ? "after" : "before";
			postMove = this.getPostMoveAction(childNode, parentNode, pos == "after" ? this.nextElementSibling(siblingNode) : siblingNode);
			lgr.trace(mname, "Get action to move ${0} ${1} ${2}", childNode, pos, siblingNode);
			refNode = siblingNode;
		}
		else {
			lgr.trace(mname, "Get action to move ${0} to ${1} of ${2}", childNode, pos, parentNode);
			postMove = this.getPostMoveAction(childNode, parentNode);
			refNode = parentNode;
		}
		return function(){
			me.moveNode(childNode, refNode, pos);
			postMove();
		};
	},
	_isBefore: function(node, sibling) {
		var idx = this._childIdx(node),
			sidx = this._childIdx(sibling);
		return idx < sidx;
	},
	_childIdx: function(node) {
		return dojo.indexOf(node.parentNode.childNodes, node);
	},
	isLTR: function() {
		if(this._isLTR !== undefined) {
			this._isLTR = (dojo.body().dir || dojo.doc.documentElement.dir || "ltr").toLowerCase() == "ltr";
		}
		return this._isLTR;
	},
	getSiblingByDirection: function(node, direction) {
		var mname = "getSiblingByDirection", lgr = this.LOGGER;
		var siblings = this.getContents(this.getContainer(node)).filter(function(c){
			return c != node;
		});
		var nodes = com.ibm.pb.screen.position.findByDirection(node, siblings, direction);
		lgr.trace(mname, "Found siblings %o in direction %o from %o", nodes, direction, node); 
		return nodes[0];
	},
	getContainerByDirection: function(node, direction) {
		var mname = "getContainerByDirection", lgr = this.LOGGER;
		var container = this.getContainer(node);
		var containers = this.getContainers().filter(function(c){
			return c != container;
		});
		var nodes = com.ibm.pb.screen.position.findByDirection(node, containers, direction);
		lgr.trace(mname, "Found containers %o in direction %o from %o", nodes, direction, node);
		return nodes[0];
	},
	getContents: function(node) {
		return dojo.query(this.contentsQuery, node);
	},
	getContainers: function() {
		return dojo.query(this.containerQuery);
	},
	getContainer: function(node) {
		return node.parentNode;
	}
});
