/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.iwidget.iEvents");

//<INTERFACE>
/**
 * This interface defines methods that's  used for event distribution and event management. Events service is accessible by using <b>"this.iContext"</b><p/>
 *  &nbsp;&nbsp;&nbsp; <code>this.iContext.iEvents</code><p/> 
 *  To distribute an event:<p/>
 *  &nbsp;&nbsp;&nbsp; <code>this.iContext.iEvents.fireEvent("eventName");</code><p/>   
 *
 * @ibm-api
 * @ibm-module iWidget2
 */
dojo.declare("com.ibm.mashups.iwidget.iEvents",null,
{	/**
            * @private
            */
    constructor:function () {
 
    },
/**
This method informs the iContext to distribute an event with proper payload and payload type
@param{String} eventName name of the event that needs to be distributed.Must not be <code>null</code>.
@param{String} payloadType optional,type of the payload.
@param{object} payload optional,object of the payload that needs to be distributed together with the event     
@type void
*/	
    fireEvent:function(/*String*/eventName,/*String*/payloadType,/*object*/payload){
    },
/**
This method simply creates a new event definition or updates an existing event if the name already exists. <br/>
It returns true if new event is created successfully or existing event is updated successfully. It returns false if it fails to create new event or update existing event.<br/>
@param{com.ibm.mashups.iwidget.IEventDescription} eventDesc IEventDescription object. Must not be <code>null</code>.
@type Boolean
@returns{Boolean} returns true if new event is created successfully or existing event is updated successfully. It returns false if it fails to create new event or update existing event.
*/	
    setEvent:function(/* iEventDescription*/ eventDesc){
	},
/**
Using this method will potentially allow optimizations to occur within the iContext. The returned boolean <br/>
indicates whether or not the request added all the described events to the iwidgets. <br/>
@param{com.ibm.mashups.iwidget.IEventDescription[]} eventDesc  array of IEventDescription object. Must not be <code>null</code>.
@type Boolean
@returns{Boolean} returns true if all the events are created successfully or existing events are updated successfully. It returns false if not all events are processed successfully.
*/	
    setEvents:function(/* iEventDescription[]*/ eventDescs){
	},
/**
This method removes an existing event description.It returns true if event is removed successfully or event doesn't exist, otherwise it returns false. <br/>
@param{String} eventName event name. Must not be <code>null</code>.
@type Boolean
@returns{Boolean} returns true if event is removed successfully or event doesn't exist, otherwise it returns false. 
*/
   removeEvent:function(/*String*/ eventName){
   },
/**
This method removes specified events.It returns true if all the events are removed successfully , otherwise it returns false. <br/>
@param{String[]} eventName event name. Must not be <code>null</code>.
@type Boolean
@returns{Boolean} returns true if all the events are removed successfully, otherwise it returns false. 
*/
   removeEvents:function(/*String[]*/ eventNames){
   },   
/**
The query method which takes a javascript object as condition, it returns a list of event descriptions which matches the given condition. <br/>
The scope of the events is limited to this iwidget instance. The returning result need to match all the conditions that's given. <br/>
For exampe, if a condition object looks like this: {type:'text', isHandled:true}<br/>
This method will return all the handled event description whose payload is text.<br/>
If no condition is provided, this method will return all the events. It returns null if no event is found for a given condition.Only predefined fields or non localized attributes should be used to define condition.
@param{Object} condition  JSON object that contains the condition. Must not be <code>null</code>.
@type com.ibm.mashups.iwidget.IEventDescription
@returns{com.ibm.mashups.iwidget.IEventDescription} returns an array of event description that matches the condition. It returns null if no event is found for a given condition. 
*/
   getEvents:function(/*Object*/ condition){
   },   
/**
This method allows to create a new IEventDescription object. All the data should be passed in as a JSON object.<br/>
Following rules applied to the JSON object:<br/>
1. Predefined fields: name,type,isHandled,isPublished,lang,handlingFn<br/>
2. Localized attributes: please see sample below<br/>
3. Non-localized attributes: please see sample below<br/>
4. Lotus Mashups provides a feature to allow a widget to register a private event so this event will not be exposed to other iwidgets by the wiring interface<br/>
&nbsp;&nbsp;&nbsp;private attribute is used to mark an event to be a private event. please see sample below<br/>
<code>
 &nbsp;&nbsp;&nbsp;var obj = {name:"sendData",  type:"text", isHandled:"true", lang:"en", handlingFn:"onSendData", <br/>
 &nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;localizedAttributes:{  <br/>
  &nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;"en":{"title":"mytitle_en","description":"mydescription_en"},<br/>
  &nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;"fr":{"title":"mytitle_fr","description":"mydescription_fr"}  <br/>
  &nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;} ,      <br/>
  &nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;attributes:{  namespace:"com.ibm.mashups", onRemoveWire:"handleRemoveWire",private:"true"} <br/>
 &nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;  };<br/>
 &nbsp;&nbsp;&nbsp;var event = this.iContext.iEvents.createEventDescription(obj);<br/>
 &nbsp;&nbsp;&nbsp;this.iContext.iEvents.setEvent(event);<br/>
</code>
@param{Object} object  JSON object that contains all the data to create an IEventDescription. Must not be <code>null</code>.
@type com.ibm.mashups.iwidget.IEventDescription
@returns{com.ibm.mashups.iwidget.IEventDescription} returns an  IEventDescription . It returns null if it fail to create the iEventDescription. 
*/ 
  createEventDescription:function(/* Object */object){
  }
	
});
//</INTERFACE>
dojo.require("com.ibm.mm.iwidget.icontext.IContextIEventsImpl");

