-- Licensed Materials - Property of IBM
-- 5724-M24
-- Copyright IBM Corporation 2011.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf preMigrateBusinessSpace700.sql
--
-- ------------------------------------------------------------------------------------
CREATE SCHEMA BSPMGTMP;

-- *****************************************************************
--
-- SCHEMA VERSION (100)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.VERSION_INFO(
    OID VARCHAR(64)    CCSID 1208 NOT NULL,
    VERSION_MAJOR   INTEGER,
    VERSION_MINOR   INTEGER,
    VERSION_RELEASE INTEGER,
    VERSION_DEV     INTEGER,
    VERSION_TIME    BIGINT,
    DESCRIPTION     VARCHAR(254) CCSID 1208,
    CONSTRAINT BSPMGTMP.PK100 PRIMARY KEY (OID)
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- CATALOG (300)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.CATALOG (
    OID         VARCHAR(64)       CCSID 1208 NOT NULL,
    ACCOUNT_OID VARCHAR(1024)     CCSID 1208 NOT NULL,
    UNIQUE_NAME VARCHAR(255)      CCSID 1208 NOT NULL,
    CREATED     BIGINT            NOT NULL,
    MODIFIED    BIGINT            NOT NULL,
    STATE       INTEGER DEFAULT 1 NOT NULL,
    CONSTRAINT BSPMGTMP.PK300 PRIMARY KEY (OID)
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE BSPMGTMP.CATALOG_LOD (
    RESOURCE_OID VARCHAR(64)       CCSID 1208 NOT NULL,
    LOCALE       VARCHAR(64)    CCSID 1208 NOT NULL,
    TITLE        VARCHAR(255)   CCSID 1208 NOT NULL,
    DESCRIPTION  VARCHAR(1024)  CCSID 1208,
    CONSTRAINT BSPMGTMP.PK301 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT BSPMGTMP.FK302 FOREIGN KEY (RESOURCE_OID) REFERENCES BSPMGTMP.CATALOG (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- CATALOG ENTRY (310)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.CATALOG_ENTRY (
    OID            			VARCHAR(64)        CCSID 1208 NOT NULL,
    CATALOG_OID    			VARCHAR(64)        CCSID 1208 NOT NULL,
    CATEGORY_OID   			VARCHAR(64)        CCSID 1208 NOT NULL,
    DEFINITION_URL 			VARCHAR(2500)      CCSID 1208 NOT NULL,
    CONTENT_URL    			VARCHAR(2500)      CCSID 1208,
    PREVIEW_URL    			VARCHAR(2500)      CCSID 1208,
    PREVIEW_THUMBNAIL_URL	VARCHAR(2500)      CCSID 1208,
    HELP_URL       			VARCHAR(2500)      CCSID 1208,
    ICON_URL       			VARCHAR(2500)      CCSID 1208,
    HUB_ENTRY_URL 			VARCHAR(2500)      CCSID 1208,
    DEF_URL_TYPE   			INTEGER            ,
    ICON_URL_TYPE  			INTEGER            ,
    CREATED        			BIGINT             NOT NULL,
    MODIFIED       			BIGINT             NOT NULL,
    STATE          			INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK310 PRIMARY KEY (OID)
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE BSPMGTMP.CATALOG_ENTRY_LOD (
    RESOURCE_OID  		VARCHAR(64)    CCSID 1208 NOT NULL,
    LOCALE        		VARCHAR(64)    CCSID 1208 NOT NULL,
    TITLE         		VARCHAR(255)   CCSID 1208 NOT NULL,
    DESCRIPTION   		VARCHAR(1024)  CCSID 1208,
    SHORT_DESCRIPTION   VARCHAR(255)   CCSID 1208,
    CONSTRAINT BSPMGTMP.PK311 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT BSPMGTMP.FK311 FOREIGN KEY (RESOURCE_OID) REFERENCES BSPMGTMP.CATALOG_ENTRY (OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE BSPMGTMP.CATALOG_ENTRY_DD (
    RESOURCE_OID  VARCHAR(64)    CCSID 1208 NOT NULL,
    NAME          VARCHAR(255)   CCSID 1208 NOT NULL,
    VALUE         VARCHAR(3000)  CCSID 1208 NOT NULL,
    CONSTRAINT BSPMGTMP.PK312 PRIMARY KEY (RESOURCE_OID, NAME),
    CONSTRAINT BSPMGTMP.FK312 FOREIGN KEY (RESOURCE_OID) REFERENCES BSPMGTMP.CATALOG_ENTRY (OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;


-- *****************************************************************
--
-- CATALOG CATEGORY (320)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.CATALOG_CATEGORY (
    OID         VARCHAR(64)         CCSID 1208 NOT NULL,
    CATALOG_OID VARCHAR(64)         CCSID 1208 NOT NULL,
    NAME        VARCHAR(255)        CCSID 1208,
    CREATED     BIGINT              NOT NULL,
    MODIFIED    BIGINT              NOT NULL,
    STATE       INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK320 PRIMARY KEY (OID),
    CONSTRAINT BSPMGTMP.FK320 FOREIGN KEY (CATALOG_OID) REFERENCES BSPMGTMP.CATALOG (OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE BSPMGTMP.CATALOG_CATEGORY_LOD (
    RESOURCE_OID VARCHAR(64)    CCSID 1208 NOT NULL,
    LOCALE       VARCHAR(64)    CCSID 1208 NOT NULL,
    TITLE        VARCHAR(255)   CCSID 1208 NOT NULL,
    DESCRIPTION  VARCHAR(1024)  CCSID 1208,
    CONSTRAINT BSPMGTMP.PK321 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT BSPMGTMP.FK321 FOREIGN KEY (RESOURCE_OID) REFERENCES BSPMGTMP.CATALOG_CATEGORY (OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;


-- *****************************************************************
--
-- CATALOG CATEGORY INCLUDES (330)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.CATALOG_CATEGORY_INC (
    OID          		VARCHAR(64)       CCSID 1208 NOT NULL,
    CATALOG_OID  		VARCHAR(64)       CCSID 1208 NOT NULL,
    CATEGORY_OID 		VARCHAR(64)       CCSID 1208 NOT NULL,
    INCLUDE_CAT  		VARCHAR(255)  	  CCSID 1208 NOT NULL,
    INCLUDE_CATEGORY	VARCHAR(255)      CCSID 1208 NOT NULL,
    CONSTRAINT BSPMGTMP.PK330 PRIMARY KEY (OID)
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- CATALOG INCLUDES (340)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.CATALOG_INC (
    OID          		VARCHAR(64)       CCSID 1208 NOT NULL,
    CATALOG_OID  		VARCHAR(64)       CCSID 1208 NOT NULL,
    INCLUDE_CAT  		VARCHAR(255)  	  CCSID 1208 NOT NULL,
    CONSTRAINT BSPMGTMP.PK340 PRIMARY KEY (OID)
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- PREFERENCE (400)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.PREFERENCE (
    OID          VARCHAR(64)        CCSID 1208 NOT NULL,
    UNIQUE_NAME  VARCHAR(255)       CCSID 1208 NOT NULL,
    PARENT_OID   VARCHAR(64)        CCSID 1208 NOT NULL,
    TYPE         INTEGER            NOT NULL,
    WDGT_INST_ID VARCHAR(255)       CCSID 1208 NOT NULL,
    ACCOUNT_ID   VARCHAR(1024)      CCSID 1208 NOT NULL,
    PAGE_ID      VARCHAR(255)       CCSID 1208 NOT NULL,
    CREATED      BIGINT             NOT NULL,
    MODIFIED     BIGINT             NOT NULL,
    STATE        INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK401 PRIMARY KEY (OID)
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- PREFERENCE NODE (WAS USED TO DEAL WITH COMPOSITE(NESTED)
--                  PREFERENCES, UNTIL DROPPED - HERE FOR REFERENCE)
--
-- *****************************************************************
--CREATE TABLE BSPMGTMP.PREFERENCE_NODE (
--    OID         CHAR(64)           CCSID 1208 NOT NULL,
--    UNIQUE_NAME VARCHAR(255)       CCSID 1208 NOT NULL,
--    PREF_OID    CHAR(64)           CCSID 1208 NOT NULL,
--    PARENT_OID  CHAR(64)           CCSID 1208 NOT NULL,
--    TYPE        INTEGER            NOT NULL,
--    CREATED     BIGINT             NOT NULL,
--    MODIFIED    BIGINT             NOT NULL,
--    STATE       INTEGER DEFAULT 1  NOT NULL,
--    CONSTRAINT BSPMGTMP.PK111 PRIMARY KEY (OID),
--    CONSTRAINT BSPMGTMP.FK111 FOREIGN KEY (PREF_OID) REFERENCES BSPMGTMP.PREFERENCE (OID) ON DELETE CASCADE
--);

-- *****************************************************************
--
-- PREFERENCE NODE VALUE (410)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.PREFERENCE_VALUE (
    OID           VARCHAR(64)        CCSID 1208 NOT NULL,
    PREF_OID      VARCHAR(64)        CCSID 1208 NOT NULL,
    NAME          VARCHAR(255)       CCSID 1208 NOT NULL,
    READ_ONLY     INTEGER DEFAULT 0  NOT NULL,
    IS_LARGE      INTEGER DEFAULT 0  NOT NULL,
    HAS_LIST      INTEGER DEFAULT 0  NOT NULL,
    VALUE         VARCHAR(1024)      CCSID 1208,
    LARGE_VALUE   CLOB(1M)           CCSID 1208,
    STATE         INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK410 PRIMARY KEY (OID),
    CONSTRAINT BSPMGTMP.FK410 FOREIGN KEY (PREF_OID) REFERENCES BSPMGTMP.PREFERENCE (OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- NAVIGATION NODE (500)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.NAVNODE (
    OID            VARCHAR(64)        CCSID 1208 NOT NULL,
    OWNER_OID      VARCHAR(1024)      CCSID 1208 NOT NULL,
    THEME_ID       VARCHAR(255)       CCSID 1208 NOT NULL,
    THEME_NAME     VARCHAR(255)       CCSID 1208 NOT NULL,
    CONTENT        BLOB(1M)           ,
    BYTE_COUNT     INTEGER            ,
    IS_ZIPPED      INTEGER DEFAULT 0  NOT NULL,
    COMMUNITY_OID  VARCHAR(64)        CCSID 1208,
    SPACE_OID      VARCHAR(64)        CCSID 1208,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK500 PRIMARY KEY (OID, OWNER_OID)
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE BSPMGTMP.NAVNODE_LOD (
    RESOURCE_OID  VARCHAR(64)    CCSID 1208 NOT NULL,
    OWNER_OID     VARCHAR(1024)  CCSID 1208 NOT NULL,
    LOCALE        VARCHAR(64)    CCSID 1208 NOT NULL,
    TITLE         VARCHAR(255)   CCSID 1208 NOT NULL,
    DESCRIPTION   VARCHAR(1024)  CCSID 1208         ,
    CONSTRAINT BSPMGTMP.FK500 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES BSPMGTMP.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE BSPMGTMP.NAVNODE_DD (
    RESOURCE_OID  VARCHAR(64)    CCSID 1208 NOT NULL,
    OWNER_OID     VARCHAR(1024)  CCSID 1208 NOT NULL,
    NAME          VARCHAR(255)   CCSID 1208 NOT NULL,
    VALUE         VARCHAR(3000)  CCSID 1208 NOT NULL,
    CONSTRAINT BSPMGTMP.PK502 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT BSPMGTMP.FK502 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES BSPMGTMP.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE
-- IN MASHUPSREGTABSPACE
);

-- *****************************************************************
--
-- NAVIGATION TREE (510)
--
-- *****************************************************************

CREATE TABLE BSPMGTMP.NAV_TREE (
    OWNER_OID    VARCHAR(1024)       CCSID 1208 NOT NULL,
    PAGE_OID     VARCHAR(64)         CCSID 1208 NOT NULL,
    PARENT_OID   VARCHAR(64)         CCSID 1208 NOT NULL,
    ORDINAL      INTEGER  DEFAULT 1  ,
    IS_VIRTUAL   INTEGER  DEFAULT 0  ,
    CONSTRAINT BSPMGTMP.PK510 PRIMARY KEY (OWNER_OID, PAGE_OID)
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- ACCESS CONTROL (600)
--
-- *****************************************************************

CREATE TABLE BSPMGTMP.COMMUNITY_DEF (
    OID            VARCHAR(64)        CCSID 1208 NOT NULL,
    OWNER_UID      VARCHAR(1024)      CCSID 1208 NOT NULL,
    RESOURCE_OID   VARCHAR(64)        CCSID 1208 NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        CCSID 1208 NOT NULL,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK600 PRIMARY KEY( OID )
)
-- IN MASHUPSREGTABSPACE
;

-- UNIQUE CONSTRAINT
ALTER TABLE BSPMGTMP.COMMUNITY_DEF ADD CONSTRAINT BSPMGTMP.UQ600 UNIQUE (OID,RESOURCE_OID);

CREATE TABLE BSPMGTMP.ACL (
    COMMUNITY_OID     VARCHAR(64)        CCSID 1208 NOT NULL,
    PARTICIPANT_UID   VARCHAR(1024)      CCSID 1208 NOT NULL,
    PARTICIPANT_TYPE  INTEGER            NOT NULL,
    PERMISSIONS       VARCHAR(255)       CCSID 1208 NOT NULL,
    CREATED           BIGINT             NOT NULL,
    MODIFIED          BIGINT             NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK610 PRIMARY KEY (COMMUNITY_OID,PARTICIPANT_UID),
    CONSTRAINT BSPMGTMP.FK611 FOREIGN KEY (COMMUNITY_OID) REFERENCES BSPMGTMP.COMMUNITY_DEF (OID) ON DELETE CASCADE
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- SPACES (700)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.SPACENODE (
    OID            VARCHAR(64)        CCSID 1208 NOT NULL,
    OWNER_OID      VARCHAR(1024)      CCSID 1208 NOT NULL,
    ROOTNAV_OID    VARCHAR(64)        CCSID 1208,
    TEMPLATE_OID   VARCHAR(64)        CCSID 1208,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK700 PRIMARY KEY (OID, OWNER_OID)
);

CREATE TABLE BSPMGTMP.SPACENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    CCSID 1208 NOT NULL,
    OWNER_OID     VARCHAR(1024)  CCSID 1208 NOT NULL,
    LOCALE        VARCHAR(64)    CCSID 1208 NOT NULL,
    TITLE         VARCHAR(255)   CCSID 1208 NOT NULL,
    DESCRIPTION   VARCHAR(1024)  CCSID 1208,
    CONSTRAINT BSPMGTMP.PK701 PRIMARY KEY (RESOURCE_OID,OWNER_OID,LOCALE),
    CONSTRAINT BSPMGTMP.FK701 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES BSPMGTMP.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE
);

CREATE TABLE BSPMGTMP.SPACENODE_DD (
    RESOURCE_OID  VARCHAR(64)    CCSID 1208 NOT NULL,
    OWNER_OID     VARCHAR(1024)  CCSID 1208 NOT NULL,
    NAME          VARCHAR(255)   CCSID 1208 NOT NULL,
    VALUE         VARCHAR(3000)  CCSID 1208 NOT NULL,
    CONSTRAINT BSPMGTMP.PK702 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT BSPMGTMP.FK702 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES BSPMGTMP.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- TEMPLATES (800)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.TEMPLATENODE (
    OID            VARCHAR(64)        CCSID 1208 NOT NULL,
    OWNER_OID      VARCHAR(1024)      CCSID 1208,
    CONTENT        BLOB(1M)           ,
    BYTE_COUNT     INTEGER            ,
    TEMPLATE_TYPE  VARCHAR(64)        CCSID 1208,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK800 PRIMARY KEY (OID)
);

CREATE TABLE BSPMGTMP.TEMPLATENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    CCSID 1208 NOT NULL,
    LOCALE        VARCHAR(64)    CCSID 1208 NOT NULL,
    TITLE         VARCHAR(255)   CCSID 1208 NOT NULL,
    DESCRIPTION   VARCHAR(1024)  CCSID 1208,
    CONSTRAINT BSPMGTMP.PK801 PRIMARY KEY (RESOURCE_OID,LOCALE),
    CONSTRAINT BSPMGTMP.FK801 FOREIGN KEY (RESOURCE_OID) REFERENCES BSPMGTMP.TEMPLATENODE (OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- ACCESS CONTROL RESOURCES (900)
--
-- *****************************************************************

CREATE TABLE BSPMGTMP.AC_RESOURCE (
    OID            VARCHAR(64)        CCSID 1208 NOT NULL,
    OWNER_UID      VARCHAR(1024)      CCSID 1208 NOT NULL,
    RESOURCE_OID   VARCHAR(64)        CCSID 1208 NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        CCSID 1208 NOT NULL,
    ROLE_BLOCKS    VARCHAR(1024)      CCSID 1208,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK900 PRIMARY KEY( RESOURCE_OID )
);

CREATE TABLE BSPMGTMP.AC_ROLE (
    AC_RESOURCE_OID   VARCHAR(64)        CCSID 1208 NOT NULL,
    ROLE_OID          VARCHAR(64)        CCSID 1208 NOT NULL,
    ROLE_NAME         VARCHAR(1024)      CCSID 1208 NOT NULL,
    ROLE_TYPE         VARCHAR(1024)      CCSID 1208,
    CREATED           BIGINT             NOT NULL,
    MODIFIED          BIGINT             NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT BSPMGTMP.PK910 PRIMARY KEY( ROLE_OID ),
    CONSTRAINT BSPMGTMP.FK911 FOREIGN KEY (AC_RESOURCE_OID) REFERENCES BSPMGTMP.AC_RESOURCE (RESOURCE_OID) ON DELETE CASCADE
);

CREATE TABLE BSPMGTMP.AC_MEMBER (
    ROLE_OID          VARCHAR(64)        CCSID 1208 NOT NULL,
    MEMBER_UID        VARCHAR(1024)      CCSID 1208 NOT NULL,
    MEMBER_TYPE       INTEGER            NOT NULL,
    CONSTRAINT BSPMGTMP.PK920 PRIMARY KEY (ROLE_OID,MEMBER_UID),
    CONSTRAINT BSPMGTMP.FK921 FOREIGN KEY (ROLE_OID) REFERENCES BSPMGTMP.AC_ROLE (ROLE_OID) ON DELETE CASCADE
);

-- *****************************************************************
--
-- FILESTORE (1000)
--
-- *****************************************************************
CREATE TABLE BSPMGTMP.FILESTORE_PATH (
    OID         VARCHAR(64)           CCSID 1208 NOT NULL,
    PARENT_OID  VARCHAR(64)           CCSID 1208 NOT NULL,
    NAME        VARCHAR(255)          CCSID 1208 NOT NULL,
    PATH        VARCHAR(255)          CCSID 1208 NOT NULL,
    LOCKED      VARCHAR(64)           CCSID 1208, 
    OWNER       VARCHAR(64)           ,             
    CREATED     BIGINT                NOT NULL,
    MODIFIED    BIGINT                NOT NULL,
    COLL_TYPE   INTEGER DEFAULT 1     NOT NULL,
    CONSTRAINT BSPMGTMP.PK1010 PRIMARY KEY (OID)
);

CREATE TABLE BSPMGTMP.FILESTORE_FILE (
    OID         VARCHAR(64)           CCSID 1208 NOT NULL,           
    F_SIZE      INTEGER               NOT NULL,
    CONTENT        BLOB(1G)           ,
    CONSTRAINT BSPMGTMP.PK1000 PRIMARY KEY (OID),
    CONSTRAINT BSPMGTMP.FK1001 FOREIGN KEY (OID) REFERENCES BSPMGTMP.FILESTORE_PATH (OID) ON DELETE CASCADE
);

--*****************************************************************
--
-- Indexing
--
--*****************************************************************
-- Catalog
CREATE INDEX BSPMGTMP.CATACCT      ON BSPMGTMP.CATALOG(ACCOUNT_OID);
CREATE INDEX BSPMGTMP.ENTRYCATGOID ON BSPMGTMP.CATALOG_ENTRY(CATALOG_OID, CATEGORY_OID);
CREATE INDEX BSPMGTMP.CATGCATOID   ON BSPMGTMP.CATALOG_CATEGORY(CATALOG_OID);
CREATE INDEX BSPMGTMP.CATINTCATOID ON BSPMGTMP.CATALOG_INC(CATALOG_OID);

-- Preferences
CREATE INDEX BSPMGTMP.PREFPARENT ON BSPMGTMP.PREFERENCE(PARENT_OID,ACCOUNT_ID);
CREATE INDEX BSPMGTMP.PREFTYPE   ON BSPMGTMP.PREFERENCE(TYPE);

-- Navigation
CREATE INDEX BSPMGTMP.PAGECOMM     ON BSPMGTMP.NAVNODE(COMMUNITY_OID);
CREATE INDEX BSPMGTMP.PAGELODOWNRS ON BSPMGTMP.NAVNODE_LOD(OWNER_OID,RESOURCE_OID);
CREATE INDEX BSPMGTMP.TREEOWPAR    ON BSPMGTMP.NAV_TREE(OWNER_OID,PARENT_OID);

-- Acl
CREATE INDEX BSPMGTMP.COMMOWNPAR ON BSPMGTMP.COMMUNITY_DEF(OWNER_UID);
CREATE INDEX BSPMGTMP.PRTTYUID   ON BSPMGTMP.ACL(PARTICIPANT_TYPE,PARTICIPANT_UID);
CREATE INDEX BSPMGTMP.PRTUID     ON BSPMGTMP.ACL(PARTICIPANT_UID);

-- AC
CREATE INDEX BSPMGTMP.AC_ROLE_RESOURCE ON BSPMGTMP.AC_ROLE(AC_RESOURCE_OID);
CREATE INDEX BSPMGTMP.AC_MEMBER_UID ON BSPMGTMP.AC_MEMBER(MEMBER_UID);
CREATE INDEX BSPMGTMP.AC_RESOURCE_OWNER ON BSPMGTMP.AC_RESOURCE(OWNER_UID,RESOURCE_OID);
